| ARp | R Documentation |
Generates a time series from an AR(p) model. The parent Gaussian
process is constructed to match a target autocorrelation structure via the
Yule-Walker equations, then transformed to a target marginal distribution
and optional intermittency (probability of zeros).
ARp(margdist, margarg, acsvalue, actfpara, n, p = NULL, p0 = 0)
margdist |
Character. Name of the target marginal distribution
(e.g. |
margarg |
Named list. Parameters of the marginal distribution passed
to |
acsvalue |
Numeric vector. Target autocorrelation structure starting
from lag 0 (i.e. |
actfpara |
List returned by |
n |
Positive integer. Length of the generated time series. |
p |
Positive integer or |
p0 |
Numeric in |
A numeric vector of length n with the following attributes:
Target marginal distribution name.
Target marginal distribution parameters.
Original (untransformed) target ACS.
Probability of zeros.
AR(p) coefficients (Yule-Walker solution).
Standard deviation of the Gaussian innovations.
The underlying Gaussian process (length n).
ACTF-transformed ACS used for the AR model.
generateTS, actpnts,
fitactf, acs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.