| BurrXII | R Documentation |
Provides density, distribution function, quantile function, random value generation, and raw moments of order r for the Burr Type XII distribution.
dburrXII(x, scale, shape1, shape2, log = FALSE)
pburrXII(q, scale, shape1, shape2, lower.tail = TRUE, log.p = FALSE)
qburrXII(p, scale, shape1, shape2, lower.tail = TRUE, log.p = FALSE)
rburrXII(n, scale, shape1, shape2)
mburrXII(r, scale, shape1, shape2)
x, q |
vector of quantiles. |
scale, shape1, shape2 |
scale and shape parameters; the shape arguments cannot be vectors (must have length one). |
log, log.p |
logical; if |
lower.tail |
logical; if |
p |
vector of probabilities. |
n |
number of observations. If |
r |
raw moment order. |
dburrXII returns a numeric vector of density values.
pburrXII returns a numeric vector of cumulative probabilities.
qburrXII returns a numeric vector of quantiles.
rburrXII returns a numeric vector of random deviates.
mburrXII returns the raw moment of order r.
Papalexiou, S.M. (2018). Unified theory for stochastic modelling of hydroclimatic processes: Preserving marginal distributions, correlation structures, and intermittency. Advances in Water Resources, 115, 234-252, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.advwatres.2018.02.013")}
fitDist, moments
## plot the density
ggplot(data.frame(x = c(0, 10)),
aes(x)) +
stat_function(fun = dburrXII,
args = list(scale = 5,
shape1 = .25,
shape2 = .75),
colour = "royalblue4") +
labs(x = "",
y = "Density") +
theme_classic()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.