DHMgenSim: Simulate one realisation using DHM circulant-embedding

View source: R/utils-internal.R

DHMgenSimR Documentation

Simulate one realisation using DHM circulant-embedding

Description

Simulates one realisation of a stationary Gaussian process from precomputed spectral values S_j via the Dietrich-Newsam-Haskard algorithm.

Usage

DHMgenSim(Sj, rn = NULL)

Arguments

Sj

numeric vector of spectral values from DHMgenSj

rn

optional vector of standard normal random numbers of length 2 * length(Sj) - 2; generated internally if NULL

Value

numeric vector of length length(Sj) - 1


CoSMoS documentation built on May 8, 2026, 1:08 a.m.