| GGamma | R Documentation |
Provides density, distribution function, quantile function, random value generation, and raw moments of order r for the generalized gamma distribution.
dggamma(x, scale, shape1, shape2, log = FALSE)
pggamma(q, scale, shape1, shape2, lower.tail = TRUE, log.p = FALSE)
qggamma(p, scale, shape1, shape2, lower.tail = TRUE, log.p = FALSE)
rggamma(n, scale, shape1, shape2)
mggamma(r, scale, shape1, shape2)
x, q |
vector of quantiles. |
scale, shape1, shape2 |
scale and shape parameters; the shape arguments cannot be vectors (must have length one). |
log, log.p |
logical; if |
lower.tail |
logical; if |
p |
vector of probabilities. |
n |
number of observations. If |
r |
raw moment order. |
dggamma returns a numeric vector of density values.
pggamma returns a numeric vector of cumulative probabilities.
qggamma returns a numeric vector of quantiles.
rggamma returns a numeric vector of random deviates.
mggamma returns the raw moment of order r.
Papalexiou, S.M., Koutsoyiannis, D. (2012). Entropy based derivation of probability distributions: A case study to daily rainfall. Advances in Water Resources, 45, 51-57, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.advwatres.2011.11.007")}
fitDist, moments
## plot the density
ggplot(data.frame(x = c(0, 20)),
aes(x)) +
stat_function(fun = dggamma,
args = list(scale = 5,
shape1 = .25,
shape2 = .75),
colour = "royalblue4") +
labs(x = "",
y = "Density") +
theme_classic()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.