| ParetoII | R Documentation |
Provides density, distribution function, quantile function, random value generation, and raw moments of order r for the Pareto type II distribution.
dparetoII(x, scale, shape, log = FALSE)
pparetoII(q, scale, shape, lower.tail = TRUE, log.p = FALSE)
qparetoII(p, scale, shape, lower.tail = TRUE, log.p = FALSE)
rparetoII(n, scale, shape)
mparetoII(r, scale, shape)
x, q |
vector of quantiles. |
scale, shape |
scale and shape parameters; the shape argument cannot be a vector (must have length one). |
log, log.p |
logical; if |
lower.tail |
logical; if |
p |
vector of probabilities. |
n |
number of observations. If |
r |
raw moment order. |
dparetoII returns a numeric vector of density values.
pparetoII returns a numeric vector of cumulative probabilities.
qparetoII returns a numeric vector of quantiles.
rparetoII returns a numeric vector of random deviates.
mparetoII returns the raw moment of order r.
fitDist, moments
## plot the density
ggplot(data.frame(x = c(0, 20)),
aes(x)) +
stat_function(fun = dparetoII,
args = list(scale = 1,
shape = .3),
colour = "royalblue4") +
labs(x = "",
y = "Density") +
theme_classic()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.