| actpntsB6 | R Documentation |
Evaluates the (rho_x, rho_z) mapping using Monte Carlo integration for the Bardossy copula dependence structure.
actpntsB6(margdist, margarg, m, p0 = 0)
margdist |
target marginal distribution |
margarg |
list of marginal distribution arguments |
m |
mean of the parent Gaussian processes controlling asymmetry |
p0 |
probability of zero values |
A data frame with columns rhoz and rhox.
Bardossy, A. (2006). Copula-based geostatistical models for groundwater quality parameters. Water Resources Research, 42(11), \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1029/2005WR004754")}
actpnts, generateMTSFast
library(CoSMoS)
x <- actpntsB6(margdist = "paretoII",
margarg = list(scale = 1, shape = .3),
m = 1,
p0 = 0)
x
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.