| checkTS | R Documentation |
Compares sample statistics of generated time series against theoretically expected values.
checkTS(TS, distbounds = c(-Inf, Inf))
TS |
a |
distbounds |
numeric vector of length 2; distribution bounds (default
|
An object of class c("checkTS", "matrix") with rows
"expected" and one row per simulated series, and columns for
mean, sd, skew, p0, acf_t1,
acf_t2, acf_t3. Attributes margdist, margarg,
and p0 are attached for use by plot.checkTS.
generateTS, plot.checkTS,
moments
library(CoSMoS)
x <- generateTS(margdist = "burrXII",
margarg = list(scale = 1,
shape1 = .75,
shape2 = .25),
acsvalue = acs(id = "weibull",
t = 0:30,
scale = 10,
shape = .75),
n = 1000, p = 30, p0 = .5, TSn = 5)
checkTS(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.