View source: R/generate-fields.R
| generateMTS | R Documentation |
Generates multiple time series with given marginals and spatiotemporal
properties. Provide (1) the output of fitVAR and (2) the number
of time steps to simulate.
generateMTS(n, STmodel)
n |
number of time steps to simulate |
STmodel |
list of arguments from |
Referring to the documentation of fitVAR for details on
computational complexity, here we report indicative simulation CPU times,
assuming model parameters are already evaluated. CPU times refer to a
Windows 10 Pro x64 laptop with Intel(R) Core(TM) i7-6700HQ CPU @ 2.60GHz,
4-core, 8 logical processors, and 32 GB RAM.
CPU time:
d = 900, p = 1, n = 1000: ~17s
d = 900, p = 1, n = 10000: ~75s
d = 900, p = 5, n = 100: ~280s
d = 900, p = 5, n = 1000: ~302s
d = 2500, p = 1, n = 1000: ~160s
d = 2500, p = 1, n = 10000: ~570s
where d denotes the number of spatial locations.
A matrix of class "matrix" with attribute STmodel.
Rows correspond to time steps and columns to spatial locations.
fitVAR, generateRF, generateMTSFast
## Simulation of a 4-dimensional vector with VAR(1) correlation structure
coord <- cbind(runif(4) * 30, runif(4) * 30)
fit <- fitVAR(
spacepoints = coord,
p = 1,
margdist = "burrXII",
margarg = list(scale = 3,
shape1 = .9,
shape2 = .2),
p0 = 0.8,
stcsid = "clayton",
stcsarg = list(scfid = "weibull",
tcfid = "weibull",
copulaarg = 2,
scfarg = list(scale = 20,
shape = 0.7),
tcfarg = list(scale = 1.1,
shape = 0.8))
)
sim <- generateMTS(n = 100, STmodel = fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.