| regenerateTS | R Documentation |
Generates additional time series using parameters already fitted by
generateTS, avoiding recomputation of the ACTF.
regenerateTS(ts, TSn = 1)
ts |
a |
TSn |
number of time series to generate |
After calling generateTS, use regenerateTS to generate
more time series with the same fitted parameters. This is faster than
re-running generateTS because the ACTF fitting step is skipped.
An object of class 'cosmosts': a list of TSn numeric
vectors of the same length as those in ts.
generateTS, ARp
library(CoSMoS)
## Fit once
x <- generateTS(margdist = "burrXII",
margarg = list(scale = 1,
shape1 = .75,
shape2 = .25),
acsvalue = acs(id = "weibull",
t = 0:30,
scale = 10,
shape = .75),
n = 1000, p = 30, p0 = .5, TSn = 3)
## Generate more realisations with the same parameters
r <- regenerateTS(x)
plot(r)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.