Learn R Programming

CoSMoS (version 2.2.0)

ACSfunctions: Parametric autocorrelation structure functions

Description

Parametric functions used internally by acs to evaluate autocorrelation at lag t. These are internal helpers and are not part of the public API; call them via acs(id, ...).

Usage

acfburrXII(t, scale, shape1, shape2)

acfparetoII(t, scale, shape)

acffgn(t, H)

acfweibull(t, scale, shape)

Value

A numeric value (or NaN if parameters are invalid).

Arguments

t

lag value (non-negative numeric).

scale

scale parameter (must be > 0).

shape, shape1, shape2

shape parameters (must be > 0).

H

Hurst exponent for the FGN model (0.5 < H < 1).