View source: R/utils-internal.R
| DHMgenSim | R Documentation |
Simulates one realisation of a stationary Gaussian process from precomputed
spectral values S_j via the Dietrich-Newsam-Haskard algorithm.
DHMgenSim(Sj, rn = NULL)
Sj |
numeric vector of spectral values from |
rn |
optional vector of standard normal random numbers of length
|
numeric vector of length length(Sj) - 1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.