Learn R Programming

CoSMoS (version 2.2.0)

DHMgenSim: Simulate one realisation using DHM circulant-embedding

Description

Simulates one realisation of a stationary Gaussian process from precomputed spectral values \(S_j\) via the Dietrich-Newsam-Haskard algorithm.

Usage

DHMgenSim(Sj, rn = NULL)

Value

numeric vector of length length(Sj) - 1

Arguments

Sj

numeric vector of spectral values from DHMgenSj

rn

optional vector of standard normal random numbers of length 2 * length(Sj) - 2; generated internally if NULL