Learn R Programming

CoSMoS (version 2.2.0)

GGamma: Generalized Gamma distribution

Description

Provides density, distribution function, quantile function, random value generation, and raw moments of order r for the generalized gamma distribution.

Usage

dggamma(x, scale, shape1, shape2, log = FALSE)

pggamma(q, scale, shape1, shape2, lower.tail = TRUE, log.p = FALSE)

qggamma(p, scale, shape1, shape2, lower.tail = TRUE, log.p = FALSE)

rggamma(n, scale, shape1, shape2)

mggamma(r, scale, shape1, shape2)

Value

dggamma returns a numeric vector of density values. pggamma returns a numeric vector of cumulative probabilities. qggamma returns a numeric vector of quantiles. rggamma returns a numeric vector of random deviates. mggamma returns the raw moment of order r.

Arguments

x, q

vector of quantiles.

scale, shape1, shape2

scale and shape parameters; the shape arguments cannot be vectors (must have length one).

log, log.p

logical; if TRUE, probabilities p are given as log(p).

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise \(P[X > x]\).

p

vector of probabilities.

n

number of observations. If length(n) > 1, the length is taken to be the number required.

r

raw moment order.

References

Papalexiou, S.M., Koutsoyiannis, D. (2012). Entropy based derivation of probability distributions: A case study to daily rainfall. Advances in Water Resources, 45, 51-57, tools:::Rd_expr_doi("10.1016/j.advwatres.2011.11.007")

See Also

fitDist, moments

Examples

Run this code

## plot the density

ggplot(data.frame(x = c(0, 20)),
       aes(x)) +
  stat_function(fun = dggamma,
                args = list(scale = 5,
                            shape1 = .25,
                            shape2 = .75),
                colour = "royalblue4") +
  labs(x = "",
       y = "Density") +
  theme_classic()

Run the code above in your browser using DataLab