| acs | R Documentation |
Provides a parametric function that describes the values of the linear autocorrelation up to desired lags. For more details on the parametric autocorrelation structures see section 3.2 in Papalexiou (2018).
acs(id, ...)
id |
autocorrelation structure id. |
... |
other arguments ( |
A numeric vector of autocorrelation values at the supplied lags.
Papalexiou, S.M. (2018). Unified theory for stochastic modelling of hydroclimatic processes: Preserving marginal distributions, correlation structures, and intermittency. Advances in Water Resources, 115, 234-252, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.advwatres.2018.02.013")}
actpnts, fitACS, fitactf
library(CoSMoS)
## specify lag
t <- 0:10
## get the ACS
f <- acs("fgn", t = t, H = .75)
b <- acs("burrXII", t = t, scale = 1, shape1 = .6, shape2 = .4)
w <- acs("weibull", t = t, scale = 2, shape = 0.8)
p <- acs("paretoII", t = t, scale = 3, shape = 0.3)
## visualize the ACS
dta <- data.table(t, f, b, w, p)
m.dta <- melt(dta, id.vars = "t")
ggplot(m.dta,
aes(x = t,
y = value,
group = variable,
colour = variable)) +
geom_point(size = 2.5) +
geom_line(lwd = 1) +
scale_color_manual(values = c("steelblue4", "red4", "green4", "darkorange"),
labels = c("FGN", "Burr XII", "Weibull", "Pareto II"),
name = "") +
labs(x = bquote(lag ~ tau),
y = "Acf") +
scale_x_continuous(breaks = t) +
theme_classic()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.