| fitDist | R Documentation |
Fits a parametric distribution to data using the Nelder-Mead simplex algorithm to minimise one of four fitting norms.
fitDist(
data,
dist,
n.points,
norm,
constrain,
opts = list(algorithm = "NLOPT_LN_NELDERMEAD", xtol_rel = 1e-08, maxeval = 10000)
)
data |
numeric vector of values to fit |
dist |
character; distribution name (e.g. |
n.points |
integer; number of ECDF points used in norm computation |
norm |
character; norm identifier — one of |
constrain |
logical; if |
opts |
list of |
An object of class "fitDist": a named list of fitted
distribution parameters with attributes dist, edf (empirical
CDF), and nfo (full nloptr output).
fitACS, plot.fitDist
x <- fitDist(rnorm(1000), "norm", 30, "N1", FALSE)
x
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.