Learn R Programming

CoSMoS (version 2.2.0)

generateMTS: Simulation of multiple time series with given marginals and spatiotemporal properties

Description

Generates multiple time series with given marginals and spatiotemporal properties. Provide (1) the output of fitVAR and (2) the number of time steps to simulate.

Usage

generateMTS(n, STmodel)

Value

A matrix of class "matrix" with attribute STmodel. Rows correspond to time steps and columns to spatial locations.

Arguments

n

number of time steps to simulate

STmodel

list of arguments from fitVAR

Details

Referring to the documentation of fitVAR for details on computational complexity, here we report indicative simulation CPU times, assuming model parameters are already evaluated. CPU times refer to a Windows 10 Pro x64 laptop with Intel(R) Core(TM) i7-6700HQ CPU @ 2.60GHz, 4-core, 8 logical processors, and 32 GB RAM.
CPU time:
d = 900, p = 1, n = 1000: ~17s
d = 900, p = 1, n = 10000: ~75s
d = 900, p = 5, n = 100: ~280s
d = 900, p = 5, n = 1000: ~302s
d = 2500, p = 1, n = 1000: ~160s
d = 2500, p = 1, n = 10000: ~570s
where \(d\) denotes the number of spatial locations.

See Also

fitVAR, generateRF, generateMTSFast

Examples

Run this code
## Simulation of a 4-dimensional vector with VAR(1) correlation structure
coord <- cbind(runif(4) * 30, runif(4) * 30)

fit <- fitVAR(
  spacepoints = coord,
  p = 1,
  margdist = "burrXII",
  margarg = list(scale = 3,
                 shape1 = .9,
                 shape2 = .2),
  p0 = 0.8,
  stcsid = "clayton",
  stcsarg = list(scfid = "weibull",
                 tcfid = "weibull",
                 copulaarg = 2,
                 scfarg = list(scale = 20,
                               shape = 0.7),
                 tcfarg = list(scale = 1.1,
                               shape = 0.8))
)

sim <- generateMTS(n = 100, STmodel = fit)

Run the code above in your browser using DataLab